@@ -59,9 +59,10 @@ def persisted_models():
 
 
 class DBCluster(dbmodels.DatabaseModelBase):
-    _data_fields = ['id', 'created', 'updated', 'name', 'task_id',
+    _data_fields = ['created', 'updated', 'name', 'task_id',
                     'tenant_id', 'datastore_version_id', 'deleted',
                     'deleted_at', 'configuration_id']
+    _table_name = 'clusters'
 
     def __init__(self, task_status, **kwargs):
         """
