@@ -17,8 +17,8 @@
 url_ref = {
     "type": "string",
     "minLength": 8,
-    "pattern": 'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]'
-               '|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
+    "pattern": r'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]'
+               r'|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
 }
 
 boolean_string = {
@@ -80,7 +80,7 @@ volume_size = {
 host_string = {
     "type": "string",
     "minLength": 1,
-    "pattern": "^[%]?[\w(-).]*[%]?$"
+    "pattern": r"^[%]?[\w(-).]*[%]?$"
 }
 
 name_string = {
@@ -102,7 +102,7 @@ volume = {
     "required": ["size"],
     "properties": {
         "size": volume_size,
-        "required": True
+        "type": non_empty_string
     }
 }
 
