@@ -44,6 +44,15 @@ path_opts = [
                help='Directory where the Trove python module is installed.'),
 ]
 
+versions_opts = [
+    cfg.StrOpt('public_endpoint', default=None,
+               help='Public URL to use for versions endpoint. The default '
+                    'is None, which will use the request\'s host_url '
+                    'attribute to populate the URL base. If Trove is '
+                    'operating behind a proxy, you will want to change '
+                    'this to represent the proxy\'s URL.')
+]
+
 common_opts = [
     cfg.IPOpt('bind_host', default='0.0.0.0',
               help='IP address the API server will listen on.'),
@@ -220,9 +229,6 @@ common_opts = [
     cfg.BoolOpt('use_nova_server_config_drive', default=True,
                 help='Use config drive for file injection when booting '
                 'instance.'),
-    cfg.BoolOpt('use_nova_server_volume', default=False,
-                help='Whether to provision a Cinder volume for the '
-                     'Nova instance.'),
     cfg.StrOpt('device_path', default='/dev/vdb',
                help='Device path for volume if volume support is enabled.'),
     cfg.StrOpt('default_datastore', default=None,
@@ -582,7 +588,7 @@ mysql_opts = [
                 deprecated_name='backup_incremental_strategy',
                 deprecated_group='DEFAULT'),
     cfg.StrOpt('root_controller',
-               default='trove.extensions.mysql.service.MySQLRootController',
+               default='trove.extensions.common.service.DefaultRootController',
                help='Root controller implementation for mysql.'),
     cfg.ListOpt('ignore_users', default=['os_admin', 'root'],
                 help='Users to exclude when listing users.',
@@ -915,8 +921,7 @@ cassandra_opts = [
                deprecated_name='restore_namespace',
                deprecated_group='DEFAULT'),
     cfg.StrOpt('root_controller',
-               default='trove.extensions.cassandra.service'
-               '.CassandraRootController',
+               default='trove.extensions.common.service.DefaultRootController',
                help='Root controller implementation for Cassandra.'),
     cfg.ListOpt('ignore_users', default=['os_admin'],
                 help='Users to exclude when listing users.'),
@@ -1186,8 +1191,7 @@ postgresql_opts = [
     cfg.ListOpt('ignore_users', default=['os_admin', 'postgres', 'root']),
     cfg.ListOpt('ignore_dbs', default=['os_admin', 'postgres']),
     cfg.StrOpt('root_controller',
-               default='trove.extensions.postgresql.service'
-               '.PostgreSQLRootController',
+               default='trove.extensions.common.service.DefaultRootController',
                help='Root controller implementation for postgresql.'),
     cfg.StrOpt('guest_log_exposed_logs', default='general',
                help='List of Guest Logs to expose for publishing.'),
@@ -1526,6 +1530,7 @@ rpcapi_cap_opts = [
 CONF = cfg.CONF
 
 CONF.register_opts(path_opts)
+CONF.register_opts(versions_opts)
 CONF.register_opts(common_opts)
 
 CONF.register_opts(database_opts, 'database')
