@@ -86,6 +86,11 @@ class UserNotFound(NotFound):
     message = _("User %(uuid)s cannot be found on the instance.")
 
 
+class RootHistoryNotFound(NotFound):
+
+    message = _("Root user has never been enabled on the instance.")
+
+
 class DatabaseNotFound(NotFound):
 
     message = _("Database %(uuid)s cannot be found on the instance.")
@@ -456,6 +461,10 @@ class SwiftNotFound(TroveError):
     message = _("Swift is disabled for tenant %(tenant_id)s.")
 
 
+class SwiftConnectionError(TroveError):
+    message = _("Cannot connect to Swift.")
+
+
 class DatabaseForUserNotInDatabaseListError(TroveError):
     message = _("The request indicates that user %(user)s should have access "
                 "to database %(database)s, but database %(database)s is not "
