@@ -18,7 +18,6 @@ from novaclient import exceptions as nova_exceptions
 from oslo_log import log as logging
 
 from trove.common import exception
-from trove.common.i18n import _
 from trove.common import remote
 from trove.network import base
 
@@ -39,7 +38,7 @@ class NovaNetwork(base.NetworkDriver):
         try:
             return self.client.security_groups.get(group_id)
         except nova_exceptions.ClientException as e:
-            LOG.exception(_('Failed to get remote security group'))
+            LOG.exception('Failed to get remote security group')
             raise exception.TroveError(str(e))
 
     def create_security_group(self, name, description):
@@ -48,14 +47,14 @@ class NovaNetwork(base.NetworkDriver):
                 name=name, description=description)
             return sec_group
         except nova_exceptions.ClientException as e:
-            LOG.exception(_('Failed to create remote security group'))
+            LOG.exception('Failed to create remote security group')
             raise exception.SecurityGroupCreationError(str(e))
 
     def delete_security_group(self, sec_group_id):
         try:
             self.client.security_groups.delete(sec_group_id)
         except nova_exceptions.ClientException as e:
-            LOG.exception(_('Failed to delete remote security group'))
+            LOG.exception('Failed to delete remote security group')
             raise exception.SecurityGroupDeletionError(str(e))
 
     def add_security_group_rule(self, sec_group_id, protocol,
@@ -70,7 +69,7 @@ class NovaNetwork(base.NetworkDriver):
 
             return sec_group_rule
         except nova_exceptions.ClientException as e:
-            LOG.exception(_('Failed to add rule to remote security group'))
+            LOG.exception('Failed to add rule to remote security group')
             raise exception.SecurityGroupRuleCreationError(str(e))
 
     def delete_security_group_rule(self, sec_group_rule_id):
@@ -78,5 +77,5 @@ class NovaNetwork(base.NetworkDriver):
             self.client.security_group_rules.delete(sec_group_rule_id)
 
         except nova_exceptions.ClientException as e:
-            LOG.exception(_('Failed to delete rule to remote security group'))
+            LOG.exception('Failed to delete rule to remote security group')
             raise exception.SecurityGroupRuleDeletionError(str(e))
