@@ -73,10 +73,10 @@ class SqlAlchemyConnection(object):
     @staticmethod
     def _exception_is_permissions_issue(msg):
         """Assert message cited a permissions issue and not something else."""
-        pos_error = re.compile(".*Host '[\w\.]*' is not allowed to connect to "
-                               "this MySQL server.*")
+        pos_error = re.compile(r".*Host '[\w\.]*' is not allowed to connect "
+                               "to this MySQL server.*")
         pos_error1 = re.compile(".*Access denied for user "
-                                "'[\w\*\!\@\#\^\&]*'@'[\w\.]*'.*")
+                                r"'[\w\*\!\@\#\^\&]*'@'[\w\.]*'.*")
         if (pos_error.match(msg) or pos_error1.match(msg)):
             return True
 
@@ -130,7 +130,7 @@ class PexpectMySqlConnection(object):
         cmd = '%s %s' % (tests.SSH_CMD, ssh_args)
         self.proc = pexpect.spawn(cmd)
         print(cmd)
-        self.proc.expect(":~\$", timeout=self.TIME_OUT)
+        self.proc.expect(r":~\$", timeout=self.TIME_OUT)
         cmd2 = "mysql --host '%s' -u '%s' '-p%s'\n" % \
                (self.host, self.user, self.password)
         print(cmd2)
@@ -152,7 +152,7 @@ class PexpectMySqlConnection(object):
         self.proc.close()
 
     def execute(self, cmd):
-        self.proc.send(cmd + "\G\n")
+        self.proc.send(cmd + "\\G\n")
         outcome = self.proc.expect(['Empty set', 'mysql>'],
                                    timeout=self.TIME_OUT)
         if outcome == 0:
